@@ -30,14 +30,14 @@ CROSS JOIN (
   SELECT
     SUM(y.a) AS a
   FROM y
-) AS "_u_0"
+) AS _u_0
 LEFT JOIN (
   SELECT
     y.a AS a
   FROM y
   GROUP BY
     y.a
-) AS "_u_1"
+) AS _u_1
   ON x.a = "_u_1"."a"
 LEFT JOIN (
   SELECT
@@ -45,7 +45,7 @@ LEFT JOIN (
   FROM y
   GROUP BY
     y.b
-) AS "_u_2"
+) AS _u_2
   ON x.a = "_u_2"."b"
 LEFT JOIN (
   SELECT
@@ -53,7 +53,7 @@ LEFT JOIN (
   FROM y
   GROUP BY
     y.a
-) AS "_u_3"
+) AS _u_3
   ON x.a = "_u_3"."a"
 LEFT JOIN (
   SELECT
@@ -64,8 +64,8 @@ LEFT JOIN (
     TRUE
   GROUP BY
     y.a
-) AS "_u_4"
-  ON x.a = "_u_4"."_u_5"
+) AS _u_4
+  ON x.a = _u_4._u_5
 LEFT JOIN (
   SELECT
     SUM(y.b) AS b,
@@ -75,8 +75,8 @@ LEFT JOIN (
     TRUE
   GROUP BY
     y.a
-) AS "_u_6"
-  ON x.a = "_u_6"."_u_7"
+) AS _u_6
+  ON x.a = _u_6._u_7
 LEFT JOIN (
   SELECT
     y.a AS a
@@ -85,8 +85,8 @@ LEFT JOIN (
     TRUE
   GROUP BY
     y.a
-) AS "_u_8"
-  ON "_u_8".a = x.a
+) AS _u_8
+  ON _u_8.a = x.a
 LEFT JOIN (
   SELECT
     y.a AS a
@@ -95,8 +95,8 @@ LEFT JOIN (
     TRUE
   GROUP BY
     y.a
-) AS "_u_9"
-  ON "_u_9".a = x.a
+) AS _u_9
+  ON _u_9.a = x.a
 LEFT JOIN (
   SELECT
     ARRAY_AGG(y.a) AS a,
@@ -106,8 +106,8 @@ LEFT JOIN (
     TRUE
   GROUP BY
     y.b
-) AS "_u_10"
-  ON "_u_10"."_u_11" = x.a
+) AS _u_10
+  ON _u_10._u_11 = x.a
 LEFT JOIN (
   SELECT
     SUM(y.a) AS a,
@@ -118,8 +118,8 @@ LEFT JOIN (
     TRUE AND TRUE AND TRUE
   GROUP BY
     y.a
-) AS "_u_12"
-  ON "_u_12"."_u_13" = x.a AND "_u_12"."_u_13" = x.b
+) AS _u_12
+  ON _u_12._u_13 = x.a AND _u_12._u_13 = x.b
 LEFT JOIN (
   SELECT
     y.a AS a
@@ -128,38 +128,38 @@ LEFT JOIN (
     TRUE
   GROUP BY
     y.a
-) AS "_u_15"
-  ON x.a = "_u_15".a
+) AS _u_15
+  ON x.a = _u_15.a
 WHERE
-  x.a = "_u_0".a
+  x.a = _u_0.a
   AND NOT "_u_1"."a" IS NULL
   AND NOT "_u_2"."b" IS NULL
   AND NOT "_u_3"."a" IS NULL
   AND (
-    x.a = "_u_4".b AND NOT "_u_4"."_u_5" IS NULL
+    x.a = _u_4.b AND NOT _u_4._u_5 IS NULL
   )
   AND (
-    x.a > "_u_6".b AND NOT "_u_6"."_u_7" IS NULL
+    x.a > _u_6.b AND NOT _u_6._u_7 IS NULL
   )
   AND (
-    None = "_u_8".a AND NOT "_u_8".a IS NULL
+    None = _u_8.a AND NOT _u_8.a IS NULL
   )
   AND NOT (
-    x.a = "_u_9".a AND NOT "_u_9".a IS NULL
+    x.a = _u_9.a AND NOT _u_9.a IS NULL
   )
   AND (
-    ARRAY_ANY("_u_10".a, _x -> _x = x.a) AND NOT "_u_10"."_u_11" IS NULL
+    ARRAY_ANY(_u_10.a, _x -> _x = x.a) AND NOT _u_10._u_11 IS NULL
   )
   AND (
     (
       (
-        x.a < "_u_12".a AND NOT "_u_12"."_u_13" IS NULL
-      ) AND NOT "_u_12"."_u_13" IS NULL
+        x.a < _u_12.a AND NOT _u_12._u_13 IS NULL
+      ) AND NOT _u_12._u_13 IS NULL
     )
-    AND ARRAY_ANY("_u_12"."_u_14", "_x" -> "_x" <> x.d)
+    AND ARRAY_ANY(_u_12._u_14, "_x" -> _x <> x.d)
   )
   AND (
-    NOT "_u_15".a IS NULL AND NOT "_u_15".a IS NULL
+    NOT _u_15.a IS NULL AND NOT _u_15.a IS NULL
   )
   AND x.a IN (
     SELECT
